from PyGitUp.gitup import GitUp
import git
import os


class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'


def warn(msg):
    print(f"{bcolors.WARNING}{msg}{bcolors.ENDC}")


def update(msg):
    print(f"{bcolors.OKGREEN}{msg}{bcolors.ENDC}")


def yes_or_no(question):
    reply = str(input(question+' (y/n): ')).lower().strip()
    if reply[0] == 'y':
        return True
    if reply[0] == 'n':
        return False
    else:
        return yes_or_no("Uhhhh... please enter ")


class BGitUp():
    dir_path = os.path.dirname(os.path.realpath(__file__))
    remoteDoesNotExist = "remote branch doesn't exist"
    missingRemoteBranches = []

    def __init__(self):
        self.gitUp = GitUp()

    def run(self):
        self.gitUp.run()

        # getting length of list of states
        states = self.gitUp.states

        # Look for any branches that are no longer connect to a remote origin
        # Iterating the index
        for i in range(len(states)):
            if states[i] == self.remoteDoesNotExist:
                branch = self.gitUp.branches[i]
                self.missingRemoteBranches.append(branch)

        missbranchesLength = len(self.missingRemoteBranches)
        if missbranchesLength > 0:
            branchPlural = "" if missbranchesLength == 1 else "es"
            thisPlural = "this" if missbranchesLength == 1 else "these"
            warn("\nBranch" + branchPlural +
                 " found that no longer exist on the emote")
            for i in range(missbranchesLength):
                warn(f"\t{self.missingRemoteBranches[i].name}")

            if yes_or_no(f"Would you like to remove {thisPlural} branch{branchPlural}?"):
                # loop over each branch and delete it locally
                repo = git.Repo(self.dir_path, search_parent_directories=True)
                for i in range(len(self.missingRemoteBranches)):
                    update(f"\t deleting {self.missingRemoteBranches[i].name}")
                    git.Head.delete(
                        repo, self.missingRemoteBranches[i].name, force=True)


def run():
    BGitUp().run()


run()



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="PyBetterGitUp",
    version="0.0.1",
    packages=find_packages(exclude=["tests"]),
    scripts=['PyBetterGitUp/bgitup.py'],
    install_requires=[
        'GitPython==2.1.1',
        'git-up==1.4.1',
        'biplist==0.7',
        'termcolor==1.1.0',
        'colorama==0.3.7'
    ],

    # Executable
    entry_points={
        'console_scripts': [
            'bgitup = bgitup:run'
        ]
    },

    # Metadata
    author="Edward Taylor",
    author_email="edweird06@users.noreply.github.com",
    description="A better package for git up",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/edweird06/BetterGitUp",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
